@@ -68,13 +68,14 @@ function(key, center, zoom=12, markers, path, span, frame, hl, sensor = 'true',
 		url <- paste(url, "&markers=", markers.string, sep="")
 	}
 	if (verbose) print(url);
+	if (verbose == -1) browser();
 	if (verbose < 2) download.file(url, destfile, mode="wb", quiet = TRUE);
 	
 	if (RETURNIMAGE){
  	  myMap <- ReadMapTile(destfile);
  	  if (GRAYSCALE) 
      	myMap$myTile <- RGB2GRAY(myMap$myTile);
- 	  invisible(myMap);
+ 	  return(myMap);
  	}
  	
 	invisible(url)
